API docs for “spamfighter.rules.model.ModelRule”

# Class s.r.m.ModelRule(object):

Part of spamfighter.rules.model View Source View In Hierarchy

Known subclasses: spamfighter.rules.model.modelClassify, spamfighter.rules.model.modelTrain

Базовый класс для правило, использующее модель анализа сообщений.

Instance Variables | model | модель анализа сообщений (type: `IModel` )
| modelName | имя модели в домене (type: `str` )
| text | текст сообщения (type: `unicode` )

Method | __init__ | Конструктор.
Method | analyze | Анализ сообщения.

def __init__(self, model='model'): (source)
Конструктор.

Parameters | model | имя модели в домене (type: `str` )

def analyze(self, domain, message, attribute='text'): (source)
overridden in spamfighter.rules.model.modelClassify, spamfighter.rules.model.modelTrain
Анализ сообщения.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего текст (type: `str` )